@@ -31,7 +31,8 @@ public class Char4 {
 	}
 
 	public void set(String id) {
-		byte[] by = id.getBytes();
+		byte[] by = new byte[4];
+		id.getBytes(0, 4, by, 0);
 		try {
 			this.set(by);
 		} catch(java.lang.CloneNotSupportedException e) {
@@ -53,7 +54,7 @@ public class Char4 {
 	}
 
 	public String getString() {
-		return new String(b, 0, b.length);
+		return new String(b, 0);
 	}
 	
 	public boolean equals(Char4 other) {
