@@ -160,7 +160,7 @@ int main(int argc, char *argv[])
   dlp_ReadAppBlock(sd, db, 0, buffer, 0xffff);
   unpack_ToDoAppInfo(&tai, buffer, 0xffff);
   
-  for (i=0;1;i++) {
+  for (i=0;;i++) {
   	struct ToDo t;
   	int attr, category;
   	recordid_t id;
@@ -189,6 +189,7 @@ int main(int argc, char *argv[])
 	fprintf(ical,"cal add $n\n");
 	
 	free_ToDo(&t);
+	
   }
 
   /* Close the database */
@@ -205,9 +206,7 @@ int main(int argc, char *argv[])
     exit(1);
   }
   
-  
-
-  for (i=0;1;i++) {
+  for (i=0;;i++) {
   	int j;
   	struct Appointment a;
   	int attr;
@@ -277,10 +276,11 @@ int main(int argc, char *argv[])
 			    a.description);
 		fprintf(ical,"$i dayrepeat %d $begin\n", a.repeatFrequency * 7);
 	    } else {
+		int ii;
 		fprintf(ical,"$i weekdays ");
-		for (i=0;i<7;i++)
-		  if (a.repeatDays[i])
-		    fprintf(ical,"%d ", i+1);
+		for (ii=0;ii<7;ii++)
+		  if (a.repeatDays[ii])
+		    fprintf(ical,"%d ", ii+1);
 		fprintf(ical,"\n");
 	    }
 	  } else if(a.repeatType == repeatYearly) {
