@@ -73,7 +73,7 @@ int main(int argc, char *argv[])
 
   printf("PUSH-OMIT-CONTEXT\n");  
   printf("CLEAR-OMIT-CONTEXT\n");  
-  for (i=0;1;i++) {
+  for (i=0;;i++) {
   	int j;
   	struct Appointment a;
   	int attr;
@@ -268,6 +268,6 @@ int main(int argc, char *argv[])
 
   pi_close(sd);  
   
-  exit(0);
+  return 0;
 }
 
